==> trinion_tp-1.0.0.tar.gz: trinion_tp/src/Controller/TovarAutocomplete.php <==
<?php
namespace Drupal\trinion_tp\Controller;


use Drupal\Component\Utility\Html;
use Drupal\node\Entity\Node;
use Drupal\taxonomy\Entity\Term;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class TovarAutocomplete {
  public function autocomplete(Request $request) {
    $referer = $request->server->get('HTTP_REFERER');
    $nds_default = 0;
    $skidka = 0;
    if (strpos($referer, '/node/add/')) {
      $parts = parse_url($referer);
      parse_str($parts['query'], $query);
      if (isset($query['comp']) && preg_match('/\((\d+)\)\s*$/', $query['comp'], $match)) {
        if ($node = Node::load($match[1])) {
          $skidka = floatval($node->get('field_tl_procent_skidki')->getString());
        }
      }
      if (isset($query['org']))
        $org_tid = $query['org'];
    }
    elseif (preg_match('/\/node\/(\d+)\/edit/', $referer, $match)) {
      $node = Node::load($match[1]);
      $org_tid = $node->get('field_tp_organizaciya')->getString();
    }
    if (!empty($org_tid) && $org = Term::load($org_tid)) {
      $nds_default = $org->get('field_tp_nds')->getString();
    }

    $string = $request->query->get('q');
    $matches = [];
    if ($string) {
      $query = \Drupal::entityQuery('node')
        ->condition('type', \Drupal::service('trinion_tp.helper')->getProductBundles(), 'IN')
        ->condition('title', $string, 'CONTAINS')
        ->range(0, 25);
      $nids = $query->accessCheck()->execute();
      if (\Drupal::config('trinion_tp.settings')->get('harakteristiki')) {
        foreach ($nids as $nid) {
          if ($tovar = Node::load($nid)) {
            $harakteristiki = \Drupal::service('trinion_tp.helper')->getHarakteristikiTovara($tovar);
            $cena = NULL;

            if (!$harakteristiki) {
              $cena = \Drupal::service('trinion_tp.helper')->getRoznichnayaCenaTovara($tovar);
              if (is_null($cena))
                $cena = '0';
            }
            $name = $tovar->label() . ' [' . $tovar->get('field_tp_artikul')->getString() . ']';
            $value = Html::escape($name);
            $label = Html::escape($name);
            if ($edinica_izmereniya = $tovar->get('field_tp_edinica_izmereniya')->first()) {
              $edinica_izmereniya_id = $edinica_izmereniya->entity->id();
              $edinica_izmereniya_name = $edinica_izmereniya->entity->label();
            }
            $matches[] = ['value' => $value, 'label' => $label, 'harakteristiki' => $harakteristiki, 'edinica_izmereniya_id' => $edinica_izmereniya_id, 'edinica_izmereniya_name' => $edinica_izmereniya_name, 'nds' => $nds_default, 'skidka' => $skidka, 'cena' => $cena];

          }
        }
      }
      else {
        foreach ($nids as $nid) {
          if ($tovar = Node::load($nid)) {
            $cena = \Drupal::service('trinion_tp.helper')->getRoznichnayaCenaTovara($tovar);

            if (is_null($cena))
              $cena = '0';
            $name = $tovar->label() . ' [' . $tovar->get('field_tp_artikul')->getString() . ']';
            $value = Html::escape($name);
            $label = Html::escape($name);
            if ($edinica_izmereniya = $tovar->get('field_tp_edinica_izmereniya')->first()) {
              $edinica_izmereniya_id = $edinica_izmereniya->entity->id();
              $edinica_izmereniya_name = $edinica_izmereniya->entity->label();
            }
            $matches[] = ['value' => $value, 'label' => $label, 'cena' => $cena, 'edinica_izmereniya_id' => $edinica_izmereniya_id, 'edinica_izmereniya_name' => $edinica_izmereniya_name, 'nds' => $nds_default, 'skidka' => $skidka,];

          }
        }
      }
    }
    return new JsonResponse($matches);
  }

  public function harakteristikaCena(Request $request) {
    $query = \Drupal::entityQuery('node')
      ->condition('type', 'cena')
      ->condition('field_tp_tip_ceny', \Drupal::config('trinion_tp.settings')->get('roznichnaya_cena_tid'))
      ->condition('field_tp_tovar', \Drupal::service('trinion_tp.helper')->tovarfromAutocomleteString($request->get('tovar'))->id())
      ->condition('field_tp_kharakteristika_tovara', $request->get('harakteristika'));
    $res = $query->accessCheck()->execute();
    if ($res) {
      $cena = Node::load(reset($res));
      $cena = $cena->get('field_tp_cena')->getString();
    }
    else
      $cena = 0;
    return new JsonResponse(['cena' => $cena]);
  }
}

==> trinion_tp-1.0.1.tar.gz: trinion_tp/src/Controller/TovarAutocomplete.php <==
<?php
namespace Drupal\trinion_tp\Controller;


use Drupal\Component\Utility\Html;
use Drupal\node\Entity\Node;
use Drupal\taxonomy\Entity\Term;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class TovarAutocomplete {
  public function autocomplete(Request $request) {
    $referer = $request->server->get('HTTP_REFERER');
    $nds_default = 0;
    $skidka = 0;
    if (strpos($referer, '/node/add/')) {
      $parts = parse_url($referer);
      parse_str($parts['query'], $query);
      if (isset($query['comp']) && preg_match('/\((\d+)\)\s*$/', $query['comp'], $match)) {
        if ($node = Node::load($match[1])) {
          $skidka = floatval($node->get('field_tl_procent_skidki')->getString());
        }
      }
      if (isset($query['org']))
        $org_tid = $query['org'];
    }
    elseif (preg_match('/\/node\/(\d+)\/edit/', $referer, $match)) {
      $node = Node::load($match[1]);
      $org_tid = $node->get('field_tp_organizaciya')->getString();
    }
    if (!empty($org_tid) && $org = Term::load($org_tid)) {
      $nds_default = $org->get('field_tp_nds')->getString();
    }

    $string = $request->query->get('q');
    $matches = [];
    if ($string) {
      $query = \Drupal::entityQuery('node')
        ->condition('type', \Drupal::service('trinion_tp.helper')->getProductBundles(), 'IN')
        ->condition('title', $string, 'CONTAINS')
        ->range(0, 25);
      $nids = $query->accessCheck()->execute();
      if (\Drupal::config('trinion_tp.settings')->get('harakteristiki')) {
        foreach ($nids as $nid) {
          if ($tovar = Node::load($nid)) {
            $harakteristiki = \Drupal::service('trinion_tp.helper')->getHarakteristikiTovara($tovar);
            $cena = NULL;

            if (!$harakteristiki) {
              $cena = \Drupal::service('trinion_tp.helper')->getRoznichnayaCenaTovara($tovar);
              if (is_null($cena))
                $cena = '0';
            }
            $name = $tovar->label() . ' [' . $tovar->get('field_tp_artikul')->getString() . ']';
            $value = Html::escape($name);
            $label = Html::escape($name);
            $opisanie = $tovar->hasField('field_tp_opisanie_tovara') ? $tovar->get('field_tp_opisanie_tovara')->first()->getValue()['summary'] : '';
            if ($edinica_izmereniya = $tovar->get('field_tp_edinica_izmereniya')->first()) {
              $edinica_izmereniya_id = $edinica_izmereniya->entity->id();
              $edinica_izmereniya_name = $edinica_izmereniya->entity->label();
            }
            $matches[] = ['value' => $value, 'label' => $label, 'harakteristiki' => $harakteristiki, 'edinica_izmereniya_id' => $edinica_izmereniya_id, 'edinica_izmereniya_name' => $edinica_izmereniya_name, 'nds' => $nds_default, 'skidka' => $skidka, 'cena' => $cena, 'opisanie' => $opisanie];

          }
        }
      }
      else {
        foreach ($nids as $nid) {
          if ($tovar = Node::load($nid)) {
            $cena = \Drupal::service('trinion_tp.helper')->getRoznichnayaCenaTovara($tovar);

            if (is_null($cena))
              $cena = '0';
            $name = $tovar->label() . ' [' . $tovar->get('field_tp_artikul')->getString() . ']';
            $value = Html::escape($name);
            $label = Html::escape($name);
            $opisanie = '';
            if ($tovar->hasField('field_tp_opisanie_tovara')) {
              if ($val = $tovar->get('field_tp_opisanie_tovara')->first())
                $opisanie = $val->getValue()['summary'];
            }
            if ($edinica_izmereniya = $tovar->get('field_tp_edinica_izmereniya')->first()) {
              $edinica_izmereniya_id = $edinica_izmereniya->entity->id();
              $edinica_izmereniya_name = $edinica_izmereniya->entity->label();
            }
            $matches[] = ['value' => $value, 'label' => $label, 'cena' => $cena, 'edinica_izmereniya_id' => $edinica_izmereniya_id, 'edinica_izmereniya_name' => $edinica_izmereniya_name, 'nds' => $nds_default, 'skidka' => $skidka, 'opisanie' => $opisanie];

          }
        }
      }
    }
    return new JsonResponse($matches);
  }

  public function harakteristikaCena(Request $request) {
    $query = \Drupal::entityQuery('node')
      ->condition('type', 'cena')
      ->condition('field_tp_tip_ceny', \Drupal::config('trinion_tp.settings')->get('roznichnaya_cena_tid'))
      ->condition('field_tp_tovar', \Drupal::service('trinion_tp.helper')->tovarfromAutocomleteString($request->get('tovar'))->id())
      ->condition('field_tp_kharakteristika_tovara', $request->get('harakteristika'));
    $res = $query->accessCheck()->execute();
    if ($res) {
      $cena = Node::load(reset($res));
      $cena = $cena->get('field_tp_cena')->getString();
    }
    else
      $cena = 0;
    return new JsonResponse(['cena' => $cena]);
  }
}
